<?php

/*//. KatePKG - A GUI (GTK2) Package Manger for KateOS.
Written by Bob Majdak Jr <bob@kateos.org>.

This program is released under the GNU GPL.

See $PREFIX/bin/katepkg for details .//*/

function package_list_updates() {

	global $w;
	global $updateable;
	global $selected;
	global $pkgmaster;
	global $pkglist;
	
	//. if we want to force a repo sync too.
	$arg = func_get_args();
	if($arg[0] == TRUE) {
		$w->ui->mode_update->info->append_text(_("Syncing with the repositories... "));
		package_fetch_updatelist(FALSE);
		$w->ui->mode_update->info->append_text(sprintf("%s.\n",_("Done")));
	}
	
	//. setting the base statusbar help for this tab.
	$w->ui->status_text(_("View which packages on your system can be updated."));

	//. change things about the window to let the user know it could be working for a bit.
	$w->update_title(sprintf("%s (%s)",_("Update Installed Packages"),_("checking repository")));
	$w->ui->mode_update->refresh->set_sensitive(FALSE);
	$w->ui->mode_update->info->clear_text();
	package_run_ui();
	
	//. freshen oneself.
	$w->ui->mode_update->list->view->set_model($w->ui->mode_update->list->empty);
	$w->ui->mode_update->list->store->clear();
	$updateable = array();

	//. run through the list and pull what is newer against what we already have.	
	foreach($pkglist as $pkg => $info) {
//		preg_match("/(.+)-(.+)-(.+)-(.+)$/",$pkg,$match);
		if($pkgmaster[$pkg]['nicebuild'] > $info['nicebuild']) {
			$updateable[] = $pkg;
		}
	}	
	
	//. fill the model with updateable packages.
	foreach($updateable as $pkg) {
		$w->ui->mode_update->list->store->append(array($pkgmaster[$pkg]['pkg'],$pkglist[$pkg]['pkg']));
	}
	
//	print_r($pkglist);
	
	//. swap to the filled model.
	$w->ui->mode_update->list->view->set_model($w->ui->mode_update->list->store);
	
	//. and tell the user we are done.	
	$w->ui->progress->set_fraction(1);
	$w->ui->mode_update->info->append_text(sprintf("%d %s.\n",count($updateable),_("packages ready for update")));
	
	//. drop anything that might be selected.
	$selected = FALSE;
	$w->ui->mode_update->selection->unselect_all();
	$w->ui->mode_update->update->set_sensitive(FALSE);	
	
	//. only click once to sort.
	if($w->ui->mode_update->list->clicked_once == FALSE) {
		$w->ui->mode_update->list->c1->clicked();
		$w->ui->mode_update->list->clicked_once = TRUE;
	}

	//. change the window to let the user know it is ready for use.
	$w->ui->mode_update->list->view->set_model($w->ui->mode_update->list->store);
	$w->update_title(_("Update Installed Packages"));
	$w->ui->mode_update->refresh->set_sensitive(TRUE);
	package_run_ui();

}

function package_view_update() {
	
	global $w;
	global $updateable;
	global $selected;
	global $updateserver;
	global $pkgmaster;
	
	list($null, $iter) = $w->ui->mode_update->selection->get_selected_rows();
	
	if(!$iter[0]) { $iter = array(); }

	$selected = array();
	
	foreach($iter as $row) {
		preg_match(
			"/(.+)-([^\-]+)-([^\-]+)-([^\-]+)$/",
			$w->ui->mode_update->list->store->get_value(
				$w->ui->mode_update->list->store->get_iter($row),
				0
			),
			$match
		);
		$selected[] = $match[1];
	}
	
	$w->ui->mode_update->info->clear_text();
	$w->ui->mode_update->info->append_text(sprintf("<b>%d %s.</b>\n",count($selected),_("packages selected")));
	foreach($selected as $pkg) {
		$w->ui->mode_update->info->append_text(sprintf("\t%s (%s)\n",$pkg,$updateserver[$pkgmaster[$pkg]['rid']]));	
	}
	
	if(count($selected > 0)) {
		$w->ui->mode_update->update->set_sensitive(TRUE);
	} else {
		$w->ui->mode_update->update->set_sensitive(FALSE);
	}
	
}

function package_dialog_update_local_browse() {

	global $w;	
	global $dialog;
	global $selected;
	global $install_browse_dir;
	
	$w->ui->set_sensitive(FALSE);
	
	//. clear the selection array.
	$selected = array();	
	
	//. build the dialog.
	$dialog = new GtkFileChooserDialog;
	$dialog->set_action(Gtk::FILE_CHOOSER_ACTION_OPEN);
	$dialog->set_transient_for($w);
	$dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
	$dialog->set_modal(TRUE);
	$dialog->set_title(_("Browse For Package..."));
	if($install_browse_dir) {
		$dialog->set_current_folder($install_browse_dir);	
	}	
	
	$dialog->add_button(_('Cancel'),Gtk::RESPONSE_CANCEL);
	$dialog->add_button(_('Install'),Gtk::RESPONSE_OK);
	
	//. add a filter for validly named packages.
	$dialog->filter = new GtkFileFIlter;
	$dialog->filter->set_name(sprintf("KateOS %s",_("Installation Packages")));
	$dialog->filter->add_pattern("*-*-*-*.tgz");
	$dialog->add_filter($dialog->filter);
	
	//. add a filter for all files.
	$dialog->nullfilter = new GtkFileFIlter;
	$dialog->nullfilter->set_name(_("All Files"));
	$dialog->nullfilter->add_pattern("*");
	$dialog->add_filter($dialog->nullfilter);
	
	//. fight.
	$click = $dialog->run();
	
	//. if we clicked install.
	if($click == Gtk::RESPONSE_OK) {
		$install_browse_dir = $dialog->get_current_folder();
		$selected[0] = $dialog->get_filename();
		$dialog->destroy(); $dialog = FALSE;

		if($selected[0]) {
			package_dialog_install(PKG_UPDATE);
		}

	//. if we clicked cancel.
	} else {
		$dialog->destroy(); $dialog = FALSE;
		$w->ui->set_sensitive(TRUE);
	}
	
}

function package_dist_update() {

	/*//. a distribution update consists of the active repositories being scanned and then
	installing everything that has an update. .//*/

	global $w;
	global $config;
	global $selected;
	global $updateable;
	
	//. disable the gui.
	$w->ui->set_sensitive(FALSE);	
	
	//. sync repo.
	package_fetch_updatelist(TRUE);
	
	//. choose updateable.
	package_list_updates();	
	$selected = $updateable;
	
	if(count($selected)) {
		//. install (this dialog also gives back the gui when done).
		package_dialog_install(PKG_UPDATE);
	} else {
		//. system is up to date.
		$w->ui->status_text_timeout(_('System is up to date'));

		//. give back the gui.
		$w->ui->set_sensitive(TRUE);
	}

}

?>